package com.xkrs.controller;

import com.xkrs.dao.QcInspectionDataSourceDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.QcInspectionDataSource;
import com.xkrs.model.qo.QcInspectionDataSourceQo;
import com.xkrs.service.DataSourceService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 17:05
 */
@RestController
public class DataSourceController {

    @Resource
    private DataSourceService dataSourceService;

    @Resource
    private QcInspectionDataSourceDao inspectionDataSourceDao;

    /**
     * 添加测量数据
     *
     * @param inspectionDataSourceQo
     * @return
     */
    @PostMapping("/insertDataSource")
    public String insertDataSource(@RequestBody QcInspectionDataSourceQo inspectionDataSourceQo) {
        return dataSourceService.insertDataSource(inspectionDataSourceQo);
    }

    /**
     * 查询某一产品的测量信息
     * 根据 批次号、机器号、物料号、模具号、零件号
     */
    @GetMapping("/selectDataSource")
    public String selectDataSource(@RequestBody QcInspectionDataSourceQo inspectionDataSourceQo) {
        String lotNo = inspectionDataSourceQo.getLotNo();
        String machineNo = inspectionDataSourceQo.getMachineNo();
        String materialNo = inspectionDataSourceQo.getMaterialNo();
        String modelNo = inspectionDataSourceQo.getModelNo();
        String partNo = inspectionDataSourceQo.getPartNo();
        Locale locale = LocaleContextHolder.getLocale();
        List<QcInspectionDataSource> inspectionDataSources = inspectionDataSourceDao.selectDataSource(lotNo, machineNo, materialNo, modelNo, partNo);
        if (inspectionDataSources == null || inspectionDataSources.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的测量信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, inspectionDataSources, locale);
    }

    /**
     * 查询全部的测量信息
     *
     * @return
     */
    @GetMapping("/selectAllSource")
    public String selectAllSource() {
        Locale locale = LocaleContextHolder.getLocale();
        List<QcInspectionDataSource> dataSourceAll = inspectionDataSourceDao.findAll();
        if (dataSourceAll == null || dataSourceAll.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的测量信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, dataSourceAll, locale);
    }
}
