package com.xkrs.dao;

import com.xkrs.model.entity.QcInspectionFile;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 15:23
 */
@Component
public interface QcInspectionFileDao extends JpaRepository<QcInspectionFile, Long>, JpaSpecificationExecutor<QcInspectionFile> {

    /**
     * 查询文件信息
     *
     * @param lotNo      批次号
     * @param machineNo  机器号
     * @param materialNo 物料号
     * @param modelNo    模具号
     * @param partNo     零件号
     * @return
     */
    QcInspectionFile selectFile(String lotNo, String machineNo, String materialNo, String modelNo, String partNo);

    /**
     * 修改模板上传信息
     *
     * @param lotNo        批次号
     * @param machineNo    机器号
     * @param materialNo   物料号
     * @param modelNo      模具号
     * @param partNo       零件号
     * @param templatePath 模版路径
     */
    @Modifying(clearAutomatically = true)
    @Query(value = "update QcInspectionFile set templatePath = ?6 where lotNo = ?1 and machineNo = ?2 and materialNo = ?3 and modelNo = ?4 and partNo = ?5")
    void updateTemplatePath(String lotNo, String machineNo, String materialNo, String modelNo, String partNo, String templatePath);

    /**
     * 修改模板载下信息
     *
     * @param lotNo      批次号
     * @param machineNo  机器号
     * @param materialNo 物料号
     * @param modelNo    模具号
     * @param partNo     零件号
     * @param filePath   文件路径
     */
    @Modifying(clearAutomatically = true)
    @Query(value = "update QcInspectionFile set filePath = ?6 where lotNo = ?1 and machineNo = ?2 and materialNo = ?3 and modelNo = ?4 and partNo = ?5")
    void updateFilePath(String lotNo, String machineNo, String materialNo, String modelNo, String partNo, String filePath);


}
